@@ -2,20 +2,20 @@ package testlib::Server;
 
 use strict;
 use warnings;
+use v5.10;
 use URI;
 use Test::More;
 use AnyEvent::Handle;
 use AnyEvent::Socket qw( tcp_server);
 use Protocol::WebSocket::Handshake::Server;
 use Protocol::WebSocket::Frame;
-use PerlX::Maybe qw( maybe );
 
 my $timeout;
 
 sub set_timeout
 {
   return if defined $timeout;
-  $timeout = AnyEvent->timer( after => 30, cb => sub {
+  $timeout = AnyEvent->timer( after => 5, cb => sub {
     diag "timeout!";
     exit 2;
   });
@@ -23,23 +23,14 @@ sub set_timeout
 
 sub start_server
 {
-  my $class = shift;
-  my $opt = { @_ };
-  $opt->{handshake} ||= sub {};
-  $opt->{customize_server_response} ||= sub {};
+  my($class, $message_cb, $handshake_cb) = @_;
   my $server_cv = AnyEvent->condvar;
 
   tcp_server undef, undef, sub {
     my $handshake = Protocol::WebSocket::Handshake::Server->new;
     my $frame     = Protocol::WebSocket::Frame->new;
   
-    my $hdl = AnyEvent::Handle->new(
-      $opt->{tls} ? (tls => 'accept', tls_ctx => $opt->{tls}) : (),
-      fh => shift,
-      on_eof => sub {
-        note("testlib::Server: on_eof called.");
-      }
-    );
+    my $hdl = AnyEvent::Handle->new( fh => shift );
   
     $hdl->on_read(
       sub {
@@ -50,9 +41,9 @@ sub start_server
           $handshake->parse($chunk);
           if($handshake->is_done)
           {
-            $opt->{customize_server_response}->($handshake);
             $hdl->push_write($handshake->to_string);
-            $opt->{handshake}->(handshake => $handshake, hdl => $hdl);
+            $handshake_cb->($handshake)
+              if $handshake_cb;
           }
           return;
         }
@@ -61,7 +52,7 @@ sub start_server
       
         while(defined(my $message = $frame->next))
         {
-          $opt->{message}->(frame => $frame, message => $message, hdl => $hdl);
+          $message_cb->($frame, $message, $hdl);
         }
       }
     );
@@ -74,24 +65,23 @@ sub start_server
   
   my $uri = URI->new('ws://127.0.0.1/echo');
   $uri->port($port);
-  $uri->scheme('wss') if $opt->{tls};
   note "$uri";
   $uri;
 }
 
 sub start_echo
 {
-  shift->start_server(message => sub {
-    my $opt = { @_ };
+  shift->start_server(sub {
+    my($frame, $message, $hdl) = @_;
     
-    return if !$opt->{frame}->is_text && !$opt->{frame}->is_binary;
+    return if !$frame->is_text && !$frame->is_binary;
 
-    $opt->{hdl}->push_write($opt->{frame}->new($opt->{message})->to_bytes);
+    $hdl->push_write($frame->new("$message")->to_bytes);
         
-    if($opt->{message} eq 'quit')
+    if($message eq 'quit')
     {
-      $opt->{hdl}->push_write($opt->{frame}->new(type => 'close')->to_bytes);
-      $opt->{hdl}->push_shutdown;
+      $hdl->push_write($frame->new(type => 'close')->to_bytes);
+      $hdl->push_shutdown;
     }
   });
 }
